%define major     1
%define libname   %mklibname %name %major
%define develname %mklibname %name -d

Name:           ktoblzcheck
Summary:        A library to check account numbers and bank codes of German banks
Version:        1.57
Release:        %mkrel 2
Group:          System/Libraries
License:        LGPLv2+
URL:            https://ktoblzcheck.sourceforge.net
Source0:        https://downloads.sourceforge.net/ktoblzcheck/%{name}-%{version}.tar.gz
Source1:        https://downloads.sourceforge.net/ktoblzcheck/ktoblzcheck-data-20240105.tar.tgz
# https://sourceforge.net/p/ktoblzcheck/bugs/23/ (author Micha Lenk)
Patch:          ktoblzcheck-fix-no-network-access.patch

BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(openpyxl)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(libcurl)

%description 
KtoBLZCheck is a library to check account numbers and bank codes of
German banks. Both a library for other programs as well as a short
command-line tool is available. It is possible to check pairs of
account numbers and bank codes (BLZ) of German banks, and to map bank
codes (BLZ) to the clear-text name and location of the bank.

%package -n     python3-%name
Group:          Development/Python
Summary:        A library to check account numbers and bank codes of German banks
Requires:       %name = %version

Provides:       python-%name = %version-%release

%description -n python3-%name
KtoBLZCheck is a library to check account numbers and bank codes of
German banks. Both a library for other programs as well as a short
command-line tool is available. It is possible to check pairs of
account numbers and bank codes (BLZ) of German banks, and to map bank
codes (BLZ) to the clear-text name and location of the bank.


%package -n     %libname
Group:          System/Libraries
Summary:        A library to check account numbers and bank codes of German banks
Requires:       %name >= %version

%description -n %libname
KtoBLZCheck is a library to check account numbers and bank codes of
German banks. Both a library for other programs as well as a short
command-line tool is available. It is possible to check pairs of
account numbers and bank codes (BLZ) of German banks, and to map bank
codes (BLZ) to the clear-text name and location of the bank.

%package -n	%develname
Group:          Development/C++
Summary:        A library to check account numbers and bank codes of German banks
Requires:       %libname = %version
Provides:       lib%name-devel = %version-%release

%description -n %develname
KtoBLZCheck is a library to check account numbers and bank codes of
German banks. Both a library for other programs as well as a short
command-line tool is available. It is possible to check pairs of
account numbers and bank codes (BLZ) of German banks, and to map bank
codes (BLZ) to the clear-text name and location of the bank.

%prep
%autosetup -p1 -a1
mv sepa* src/bankdata/sepa/
mv *.db src/bankdata/
mv blz*.txt src/bankdata/
mv *data* src/bankdata/

%build
%cmake -DENABLE_BANKDATA_DOWNLOAD=OFF \
       -DINSTALL_RAW_BANKDATA_FILE=ON
%cmake_build

%install
%cmake_install

%files -n %libname
%license COPYING
%{_libdir}/libktoblzcheck.so.%{major}{,.*}

%files -n %develname
%doc README.md
%{_libdir}/libktoblzcheck.so
%{_includedir}/iban.h
%{_includedir}/ktoblzcheck*.h
%{_libdir}/pkgconfig/ktoblzcheck.pc
%{_libdir}/cmake/KtoBlzCheck/

%files -n python3-%name
%doc README.md
%{python3_sitearch}/*.py*
%{python3_sitearch}/__pycache__/*

%files
%doc README.md ChangeLog NEWS
%doc %{_docdir}/%{name}/
%license COPYING
%{_bindir}/ktoblzcheck
%{_bindir}/ktoblzupdate
%{_bindir}/ibanchk
%{_datadir}/ktoblzcheck/*
%{_mandir}/man1/ktoblzcheck.1*
%{_mandir}/man1/ibanchk.1*


%changelog
* Tue Mar 04 2025 wally <wally> 1.57-2.mga10
+ Revision: 2160381
- rebuild for python3.13

* Mon Mar 03 2025 papoteur <papoteur> 1.57-1.mga10
+ Revision: 2159577
- new version 1.57
- add data
- fix cmake to not fail when network is disabled
- rebuild for python 3.13

* Mon Jan 01 2024 daviddavid <daviddavid> 1.53-3.mga10
+ Revision: 2025017
- revert back to 1.53 release (1.54 build is bogus for now)
- new version: 1.54
- rebuild for py3.12

* Sat Mar 19 2022 umeabot <umeabot> 1.53-2.mga9
+ Revision: 1799346
- Mageia 9 Mass Rebuild

* Tue Mar 01 2022 mrambo3501 <mrambo3501> 1.53-1.mga9
+ Revision: 1787282
- version 1.53
- rebuild for python-3.10

* Mon Mar 22 2021 daviddavid <daviddavid> 1.52-2.mga9
+ Revision: 1707819
- rebuild for python 3.9

* Mon Feb 24 2020 daviddavid <daviddavid> 1.52-1.mga8
+ Revision: 1549714
- new version: 1.52
- switch to cmake build system
- port to python3
- drop python2 support
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 1.49-2.mga7
+ Revision: 1298678
- Mageia 7 Mass Rebuild

* Sun Oct 08 2017 daviddavid <daviddavid> 1.49-1.mga7
+ Revision: 1170086
- new version: 1.49
- rename python-ktoblzcheck to python2-ktoblzcheck

* Thu Apr 28 2016 daviddavid <daviddavid> 1.40-9.mga6
+ Revision: 1007036
- use new python macros

* Thu Jan 07 2016 neoclust <neoclust> 1.40-8.mga6
+ Revision: 920297
- Use new python macros

* Wed Oct 15 2014 umeabot <umeabot> 1.40-7.mga5
+ Revision: 750673
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.40-6.mga5
+ Revision: 726686
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.40-5.mga5
+ Revision: 681230
- Mageia 5 Mass Rebuild

* Sat May 31 2014 pterjan <pterjan> 1.40-4.mga5
+ Revision: 628283
- Rebuild for new Python

* Fri Oct 18 2013 umeabot <umeabot> 1.40-3.mga4
+ Revision: 506757
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 1.40-2.mga3
+ Revision: 356531
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Sep 07 2012 fwang <fwang> 1.40-1.mga3
+ Revision: 289198
- update tarball
- new version 1.40

* Thu Jun 16 2011 fwang <fwang> 1.33-1.mga2
+ Revision: 108118
- update file list
- new version 1.33

* Sun May 15 2011 pterjan <pterjan> 1.28-2.mga1
+ Revision: 98932
- Rebuild for fixed find-requires

* Thu Feb 10 2011 spuhler <spuhler> 1.28-1.mga1
+ Revision: 49692
- removed buildroot definition from .spec
  removed the if mdkversion lines
- imported package ktoblzcheck


* Sat Feb 05 2011 Götz Waschk <waschk@mandriva.org> 1.28-1mdv2011.0
+ Revision: 636198
- update to new version 1.28

* Mon Nov 01 2010 Götz Waschk <waschk@mandriva.org> 1.24-2mdv2011.0
+ Revision: 591586
- rebuild for new python 2.7

* Sun Jan 31 2010 Götz Waschk <waschk@mandriva.org> 1.24-1mdv2010.1
+ Revision: 498734
- update to new version 1.24

* Sat Jun 20 2009 Götz Waschk <waschk@mandriva.org> 1.22-1mdv2010.0
+ Revision: 387517
- update to new version 1.22

* Mon Feb 09 2009 Götz Waschk <waschk@mandriva.org> 1.21-1mdv2009.1
+ Revision: 338967
- update to new version 1.21

* Fri Dec 26 2008 Funda Wang <fwang@mandriva.org> 1.20-2mdv2009.1
+ Revision: 319424
- rebuild for new python

* Fri Nov 14 2008 Götz Waschk <waschk@mandriva.org> 1.20-1mdv2009.1
+ Revision: 303115
- update to new version 1.20

* Tue Aug 12 2008 Götz Waschk <waschk@mandriva.org> 1.19-1mdv2009.0
+ Revision: 271238
- new version
- update license

* Wed Aug 06 2008 Thierry Vignaud <tv@mandriva.org> 1.18-2mdv2009.0
+ Revision: 264768
- rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Sun May 18 2008 Götz Waschk <waschk@mandriva.org> 1.18-1mdv2009.0
+ Revision: 208784
- new version

* Sat Mar 01 2008 Götz Waschk <waschk@mandriva.org> 1.17-1mdv2008.1
+ Revision: 177442
- new version

* Mon Feb 25 2008 Götz Waschk <waschk@mandriva.org> 1.16-1mdv2008.1
+ Revision: 174607
- new version

* Sun Jan 13 2008 Thierry Vignaud <tv@mandriva.org> 1.15-2mdv2008.1
+ Revision: 150434
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Wed Sep 05 2007 Götz Waschk <waschk@mandriva.org> 1.15-1mdv2008.0
+ Revision: 79987
- new version
- drop patch
- new devel name

* Fri Jun 08 2007 Götz Waschk <waschk@mandriva.org> 1.8-2mdv2008.0
+ Revision: 37223
- Import ktoblzcheck



* Wed Jun  7 2006 Götz Waschk <waschk@mandriva.org> 1.8-2mdv2007.0
- fix build

* Tue Dec  6 2005 Götz Waschk <waschk@mandriva.org> 1.8-1mdk
- initial package
